#
# spec file for package ghc-cabal-helper
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name cabal-helper
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.7.3.0
Release:        16.34
Summary:        Simple interface to some of Cabal's configuration state used by ghc-mod
License:        AGPL-3.0+
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/1.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-temporary-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-utf8-string-devel
%if %{with tests}
BuildRequires:  cabal-install
BuildRequires:  ghc-extra-devel
BuildRequires:  ghc-unix-devel
%endif

%description
'cabal-helper' provides a library which wraps the internal use of an executable
to lift the restrictions imposed by linking against versions of GHC before
'7.10'. This has the pleasant side effect of isolating the user from having to
deal with Cabal version changes manually as 'cabal-helper' can simply recompile
it's helper program automatically as needed.

'cabal-helper' uses a wrapper executable to compile the actual cabal-helper
executable at runtime while linking against an arbitrary version of Cabal.
This runtime-compiled helper executable is then used to extract various bits
and peices from Cabal's on disk state (dist/setup-config) written by it's
configure command.

In addition to this the wrapper executable also supports installing any version
of Cabal from hackage in case it cannot be found in any available package
database. The wrapper installs these instances of the Cabal library into a
private package database so as to not interfere with the user's packages.

Furthermore the wrapper supports one special case namely reading a state file
for Cabal itself. This is needed as Cabal compiles it's Setup.hs using itself
and not using any version of Cabal installed in any package database.

'cabal-helper' can compile with 'Cabal >= 1.14' but requires 'Cabal >= 1.16' at
runtime.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%define cabal_configure_options --libexecdir=%{_libexecdir}
%ghc_lib_build

%install
%ghc_lib_install
ln -s %{pkg_name}-%{version} %{buildroot}%{_libexecdir}/%{_arch}-%{_os}-ghc-%{ghc_version}/%{pkg_name}

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%doc LICENSE
%dir %{_libexecdir}/%{_arch}-%{_os}-ghc-%{ghc_version}
%dir %{_libexecdir}/%{_arch}-%{_os}-ghc-%{ghc_version}/%{pkg_name}-%{version}
%{_libexecdir}/%{_arch}-%{_os}-ghc-%{ghc_version}/%{pkg_name}
%{_libexecdir}/%{_arch}-%{_os}-ghc-%{ghc_version}/%{pkg_name}-%{version}/cabal-helper-wrapper

%files devel -f %{name}-devel.files
%doc README.md

%changelog
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Sun Feb 12 2017 psimons@suse.com
- Update to version 0.7.3.0 revision 1 with cabal2obs.
* Wed Jan 18 2017 psimons@suse.com
- Update to version 0.7.2.0 revision 1 with cabal2obs.
* Thu Sep 15 2016 psimons@suse.com
- Update to version 0.7.2.0 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.6.3.1 revision 1 with cabal2obs.
* Fri Jan 22 2016 mimi.vx@gmail.com
- update to 0.6.3.1
* Mon Jan 11 2016 mimi.vx@gmail.com
- update to 0.6.3.0
* Wed Dec 23 2015 mimi.vx@gmail.com
- update to 0.6.2.0
* Mon Nov  2 2015 mimi.vx@gmail.com
- update to 0.6.1.0
* Mon Sep 28 2015 mimi.vx@gmail.com
- update to 0.6.0.0
* Sun Aug 30 2015 mimi.vx@gmail.com
- rework %%install
* Fri Aug 28 2015 mimi.vx@gmail.com
- move cabal-helper-wrapper to %%_libexecdir
* Wed Aug 26 2015 mimi.vx@gmail.com
- update to 0.5.2.0
* Thu Aug 13 2015 mimi.vx@gmail.com
- initial commit
